@@ -418,7 +418,7 @@ class Dumpulator(Architecture):
         self.regs = Registers(self._uc, self._x64)
         self.args = Arguments(self._uc, self.regs, self._x64)
         self._allocate_base = None
-        self._allocate_size = 0x10000
+        self._allocate_size = 1024 * 1024 * 10  # NOTE: 10 megs
         self._allocate_ptr = None
         self._setup_emulator()
         self.exit_code = None
@@ -819,14 +819,25 @@ def _hook_syscall(uc: Uc, dp: Dumpulator):
             argspec = inspect.getfullargspec(cb)
             args = []
 
+            def syscall_arg(index):
+                if index == 0 and dp.ptr_size() == 8:
+                    return dp.regs.r10
+                return dp.args[index]
+
             print(f"syscall: {name}(")
             for i in range(0, argcount):
                 argname = argspec.args[1 + i]
                 argtype = argspec.annotations[argname]
+                argvalue = syscall_arg(i)
                 if issubclass(argtype, PVOID):
-                    argvalue = argtype(dp.args[i], dp)
+                    argvalue = argtype(argvalue, dp)
+                elif issubclass(argtype, Enum):
+                    try:
+                        argvalue = argtype(dp.args[i])
+                    except KeyError as x:
+                        raise Exception(f"Unknown enum value {dp.args[i]} for {type(argtype)}")
                 else:
-                    argvalue = argtype(dp.args[i])
+                    argvalue = argtype(argvalue)
                 args.append(argvalue)
 
                 comma = ","
@@ -839,6 +850,7 @@ def _hook_syscall(uc: Uc, dp: Dumpulator):
                 status = cb(dp, *args)
                 print(f"status = {status:x}")
                 dp.regs.cax = status
+                dp.regs.ccx = dp.regs.cip + 2
             except Exception as exc:
                 sys.stderr = sys.stdout
                 traceback.print_exception(type(exc), exc, exc.__traceback__)
